<?php

return array(
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Nenhum',
    'Edit' => 'Editar',
    'Remove' => 'Remover',
    'Yes' => 'Sim',
    'No' => 'Não',
    'cancel' => 'cancelar',
    'or' => 'ou',
    'Yellow' => 'Amarelo',
    'Blue' => 'Azul',
    'Green' => 'Verde',
    'Purple' => 'Roxo',
    'Red' => 'Vermelho',
    'Orange' => 'Laranja',
    'Grey' => 'Cinza',
    'Brown' => 'Castanho',
    'Deep Orange' => 'Laranja escuro',
    'Dark Grey' => 'Cinza escuro',
    'Pink' => 'Rosa',
    'Teal' => 'Turquesa',
    'Cyan' => 'Azul intenso',
    'Lime' => 'Verde limão',
    'Light Green' => 'Verde claro',
    'Amber' => 'Âmbar',
    'Save' => 'Guardar',
    'Login' => 'Login',
    'Official website:' => 'Site oficial:',
    'Unassigned' => 'Não Atribuída',
    'View this task' => 'Ver esta tarefa',
    'Remove user' => 'Remover utilizador',
    'Do you really want to remove this user: "%s"?' => 'Pretende mesmo remover este utilizador: "%s"?',
    'All users' => 'Todos os utilizadores',
    'Username' => 'Nome de utilizador',
    'Password' => 'Senha',
    'Administrator' => 'Administrador',
    'Sign in' => 'Entrar',
    'Users' => 'Utilizadores',
    'Forbidden' => 'Proibido',
    'Access Forbidden' => 'Acesso negado',
    'Edit user' => 'Editar utilizador',
    'Logout' => 'Sair',
    'Bad username or password' => 'Utilizador ou senha inválidos',
    'Edit project' => 'Editar projeto',
    'Name' => 'Nome',
    'Projects' => 'Projetos',
    'No project' => 'Nenhum projeto',
    'Project' => 'Projeto',
    'Status' => 'Estado',
    'Tasks' => 'Tarefas',
    'Board' => 'Quadro',
    'Actions' => 'Acções',
    'Inactive' => 'Inactivo',
    'Active' => 'Activo',
    'Unable to update this board.' => 'Não foi possível actualizar este quadro.',
    'Disable' => 'Desactivar',
    'Enable' => 'Activar',
    'New project' => 'Novo projeto',
    'Do you really want to remove this project: "%s"?' => 'Tem a certeza que quer remover este projeto: "%s" ?',
    'Remove project' => 'Remover projeto',
    'Edit the board for "%s"' => 'Editar o quadro para "%s"',
    'Add a new column' => 'Adicionar uma nova coluna',
    'Title' => 'Título',
    'Assigned to %s' => 'Designado para %s',
    'Remove a column' => 'Remover uma coluna',
    'Unable to remove this column.' => 'Não foi possível remover esta coluna.',
    'Do you really want to remove this column: "%s"?' => 'Tem a certeza que quer remover esta coluna: "%s"?',
    'Settings' => 'Configurações',
    'Application settings' => 'Configurações da aplicação',
    'Language' => 'Idioma',
    'Webhook token:' => 'Token de webhooks:',
    'API token:' => 'API Token:',
    'Database size:' => 'Tamanho da base de dados:',
    'Download the database' => 'Download da base de dados',
    'Optimize the database' => 'Otimizar a base de dados',
    '(VACUUM command)' => '(Comando VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Arquivo Sqlite comprimido com Gzip)',
    'Close a task' => 'Finalizar uma tarefa',
    'Column' => 'Coluna',
    'Color' => 'Cor',
    'Assignee' => 'Assignado',
    'Create another task' => 'Criar outra tarefa',
    'New task' => 'Nova tarefa',
    'Open a task' => 'Abrir uma tarefa',
    'Do you really want to open this task: "%s"?' => 'Tem a certeza que quer abrir esta tarefa: "%s"?',
    'Back to the board' => 'Voltar ao quadro',
    'There is nobody assigned' => 'Não há ninguém assignado',
    'Column on the board:' => 'Coluna no quadro:',
    'Close this task' => 'Finalizar esta tarefa',
    'Open this task' => 'Abrir esta tarefa',
    'There is no description.' => 'Não há descrição.',
    'Add a new task' => 'Adicionar uma nova tarefa',
    'The username is required' => 'O nome de utilizador é obrigatório',
    'The maximum length is %d characters' => 'O tamanho máximo é %d caracteres',
    'The minimum length is %d characters' => 'O tamanho mínimo é %d caracteres',
    'The password is required' => 'A senha é obrigatória',
    'This value must be an integer' => 'O valor deve ser um número inteiro',
    'The username must be unique' => 'O nome de utilizador deve ser único',
    'The user id is required' => 'O ID de utilizador é obrigatório',
    'Passwords don\'t match' => 'As senhas não coincidem',
    'The confirmation is required' => 'A confirmação é obrigatória',
    'The project is required' => 'O projeto é obrigatório',
    'The id is required' => 'O ID é obrigatório',
    'The project id is required' => 'O ID do projeto é obrigatório',
    'The project name is required' => 'O nome do projeto é obrigatório',
    'The title is required' => 'O título é obrigatório',
    'Settings saved successfully.' => 'Configurações guardadas com sucesso.',
    'Unable to save your settings.' => 'Não é possível guardar as suas configurações.',
    'Database optimization done.' => 'Otimização da base de dados finalizada.',
    'Your project has been created successfully.' => 'Projeto foi criado com sucesso.',
    'Unable to create your project.' => 'Não é possível criar o projeto.',
    'Project updated successfully.' => 'Projeto actualizado com sucesso.',
    'Unable to update this project.' => 'Não é possível actualizar este projeto.',
    'Unable to remove this project.' => 'Não é possível remover este projeto.',
    'Project removed successfully.' => 'Projeto removido com sucesso.',
    'Project activated successfully.' => 'Projeto activado com sucesso.',
    'Unable to activate this project.' => 'Não é possível activar este projeto.',
    'Project disabled successfully.' => 'Projeto desactivado com sucesso.',
    'Unable to disable this project.' => 'Não é possível desactivar este projeto.',
    'Unable to open this task.' => 'Não é possível abrir esta tarefa.',
    'Task opened successfully.' => 'Tarefa aberta com sucesso.',
    'Unable to close this task.' => 'Não é possível finalizar esta tarefa.',
    'Task closed successfully.' => 'Tarefa finalizada com sucesso.',
    'Unable to update your task.' => 'Não é possível actualizar a sua tarefa.',
    'Task updated successfully.' => 'Tarefa actualizada com sucesso.',
    'Unable to create your task.' => 'Não é possível criar a sua tarefa.',
    'Task created successfully.' => 'Tarefa criada com sucesso.',
    'User created successfully.' => 'Utilizador criado com sucesso.',
    'Unable to create your user.' => 'Não é possível criar o seu Utilizador.',
    'User updated successfully.' => 'Utilizador actualizado com sucesso.',
    'User removed successfully.' => 'Utilizador removido com sucesso.',
    'Unable to remove this user.' => 'Não é possível remover este Utilizador.',
    'Board updated successfully.' => 'Quadro actualizado com sucesso.',
    'Ready' => 'Pronto',
    'Backlog' => 'Backlog',
    'Work in progress' => 'Em andamento',
    'Done' => 'Finalizado',
    'Application version:' => 'Versão da aplicação:',
    'Id' => 'Id',
    'Public link' => 'Link público',
    'Timezone' => 'Fuso horário',
    'Sorry, I didn\'t find this information in my database!' => 'Desculpe, não encontrei esta informação na minha base de dados!',
    'Page not found' => 'Página não encontrada',
    'Complexity' => 'Complexidade',
    'Task limit' => 'Limite da tarefa',
    'Task count' => 'Número de tarefas',
    'User' => 'Utilizador',
    'Comments' => 'Comentários',
    'Comment is required' => 'Comentário é obrigatório',
    'Comment added successfully.' => 'Comentário adicionado com sucesso.',
    'Unable to create your comment.' => 'Não é possível criar o seu comentário.',
    'Due Date' => 'Data de vencimento',
    'Invalid date' => 'Data inválida',
    'Automatic actions' => 'Acções automáticas',
    'Your automatic action has been created successfully.' => 'A sua acção automática foi criada com sucesso.',
    'Unable to create your automatic action.' => 'Não é possível criar a sua acção automática.',
    'Remove an action' => 'Remover uma acção',
    'Unable to remove this action.' => 'Não é possível remover esta acção.',
    'Action removed successfully.' => 'Acção removida com sucesso.',
    'Automatic actions for the project "%s"' => 'Acções automáticas para o projeto "%s"',
    'Add an action' => 'Adicionar Acção',
    'Event name' => 'Nome do evento',
    'Action' => 'Acção',
    'Event' => 'Evento',
    'When the selected event occurs execute the corresponding action.' => 'Quando o evento selecionado ocorrer execute a acção correspondente.',
    'Next step' => 'Próximo passo',
    'Define action parameters' => 'Definir parêmetros da acção',
    'Do you really want to remove this action: "%s"?' => 'Tem a certeza que quer remover esta acção: "%s"?',
    'Remove an automatic action' => 'Remover uma acção automática',
    'Assign the task to a specific user' => 'Designar a tarefa para um utilizador específico',
    'Assign the task to the person who does the action' => 'Designar a tarefa para a pessoa que executa a acção',
    'Duplicate the task to another project' => 'Duplicar a tarefa para um outro projeto',
    'Move a task to another column' => 'Mover a tarefa para outra coluna',
    'Task modification' => 'Modificação de tarefa',
    'Task creation' => 'Criação de tarefa',
    'Closing a task' => 'A finalizar uma tarefa',
    'Assign a color to a specific user' => 'Designar uma cor para um utilizador específico',
    'Position' => 'Posição',
    'Duplicate to project' => 'Duplicar para outro projeto',
    'Duplicate' => 'Duplicar',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Comentário actualizado com sucesso.',
    'Unable to update your comment.' => 'Não é possível actualizar o seu comentário.',
    'Remove a comment' => 'Remover um comentário',
    'Comment removed successfully.' => 'Comentário removido com sucesso.',
    'Unable to remove this comment.' => 'Não é possível remover este comentário.',
    'Do you really want to remove this comment?' => 'Tem a certeza que quer remover este comentário?',
    'Current password for the user "%s"' => 'Senha atual para o utilizador "%s"',
    'The current password is required' => 'A senha atual é obrigatória',
    'Wrong password' => 'Senha incorreta',
    'Unknown' => 'Desconhecido',
    'Last logins' => 'Últimos logins',
    'Login date' => 'Data de login',
    'Authentication method' => 'Método de autenticação',
    'IP address' => 'Endereço IP',
    'User agent' => 'User Agent',
    'Persistent connections' => 'Conexões persistentes',
    'No session.' => 'Nenhuma sessão.',
    'Expiration date' => 'Data de expiração',
    'Remember Me' => 'Lembre-se de mim',
    'Creation date' => 'Data de criação',
    'Everybody' => 'Todos',
    'Open' => 'Aberto',
    'Closed' => 'Finalizado',
    'Search' => 'Pesquisar',
    'Nothing found.' => 'Nada encontrado.',
    'Due date' => 'Data de vencimento',
    'Description' => 'Descrição',
    '%d comments' => '%d comentários',
    '%d comment' => '%d comentário',
    'Email address invalid' => 'Endereço de e-mail inválido',
    'Your external account is not linked anymore to your profile.' => 'A sua conta externa já não se encontra vinculada a este perfil',
    'Unable to unlink your external account.' => 'Não foi possivel desvincular a sua conta externa',
    'External authentication failed' => 'Autenticação externa falhou',
    'Your external account is linked to your profile successfully.' => 'A sua conta externa foi vinculada com sucesso ao seu perfil',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Tarefa removida com sucesso.',
    'Unable to remove this task.' => 'Não foi possível remover esta tarefa.',
    'Remove a task' => 'Remover uma tarefa',
    'Do you really want to remove this task: "%s"?' => 'Tem a certeza que quer remover esta tarefa: "%s"',
    'Assign automatically a color based on a category' => 'Atribuir automaticamente uma cor com base numa categoria',
    'Assign automatically a category based on a color' => 'Atribuir automaticamente uma categoria com base numa cor',
    'Task creation or modification' => 'Criação ou modificação de tarefa',
    'Category' => 'Categoria',
    'Category:' => 'Categoria:',
    'Categories' => 'Categorias',
    'Your category has been created successfully.' => 'A sua categoria foi criada com sucesso.',
    'This category has been updated successfully.' => 'A sua categoria foi actualizada com sucesso.',
    'Unable to update this category.' => 'Não foi possível actualizar a sua categoria.',
    'Remove a category' => 'Remover uma categoria',
    'Category removed successfully.' => 'Categoria removida com sucesso.',
    'Unable to remove this category.' => 'Não foi possível remover esta categoria.',
    'Category modification for the project "%s"' => 'Modificação de categoria para o projeto "%s"',
    'Category Name' => 'Nome da Categoria',
    'Add a new category' => 'Adicionar uma nova categoria',
    'Do you really want to remove this category: "%s"?' => 'Tem a certeza que quer remover esta categoria: "%s"',
    'All categories' => 'Todas as categorias',
    'No category' => 'Nenhuma categoria',
    'The name is required' => 'O nome é obrigatório',
    'Remove a file' => 'Remover um arquivo',
    'Unable to remove this file.' => 'Não foi possível remover este arquivo.',
    'File removed successfully.' => 'Arquivo removido com sucesso.',
    'Attach a document' => 'Anexar um documento',
    'Do you really want to remove this file: "%s"?' => 'Tem a certeza que quer remover este arquivo: "%s"',
    'Attachments' => 'Anexos',
    'Edit the task' => 'Editar a tarefa',
    'Add a comment' => 'Adicionar um comentário',
    'Edit a comment' => 'Editar um comentário',
    'Summary' => 'Resumo',
    'Time tracking' => 'Rastreamento de tempo',
    'Estimate:' => 'Estimado:',
    'Spent:' => 'Gasto:',
    'Do you really want to remove this sub-task?' => 'Tem a certeza que quer remover esta subtarefa?',
    'Remaining:' => 'Restante:',
    'hours' => 'horas',
    'estimated' => 'estimado',
    'Sub-Tasks' => 'Subtarefas',
    'Add a sub-task' => 'Adicionar uma subtarefa',
    'Original estimate' => 'Estimativa original',
    'Create another sub-task' => 'Criar uma outra subtarefa',
    'Time spent' => 'Tempo gasto',
    'Edit a sub-task' => 'Editar uma subtarefa',
    'Remove a sub-task' => 'Remover uma subtarefa',
    'The time must be a numeric value' => 'O tempo deve ser um valor numérico',
    'Todo' => 'A fazer',
    'In progress' => 'Em andamento',
    'Sub-task removed successfully.' => 'Subtarefa removida com sucesso.',
    'Unable to remove this sub-task.' => 'Não foi possível remover esta subtarefa.',
    'Sub-task updated successfully.' => 'Subtarefa atualizada com sucesso.',
    'Unable to update your sub-task.' => 'Não foi possível atualizar a sua subtarefa.',
    'Unable to create your sub-task.' => 'Não é possível criar a sua subtarefa.',
    'Maximum size: ' => 'Tamanho máximo: ',
    'Display another project' => 'Mostrar outro projeto',
    'Created by %s' => 'Criado por %s',
    'Tasks Export' => 'Exportar Tarefas',
    'Start Date' => 'Data inicial',
    'Execute' => 'Executar',
    'Task Id' => 'ID da Tarefa',
    'Creator' => 'Criado por',
    'Modification date' => 'Data da modificação',
    'Completion date' => 'Data da finalização',
    'Clone' => 'Clonar',
    'Project cloned successfully.' => 'Projeto clonado com sucesso.',
    'Unable to clone this project.' => 'Não foi possível clonar este projeto.',
    'Enable email notifications' => 'Activar notificações por e-mail',
    'Task position:' => 'Posição da tarefa:',
    'The task #%d has been opened.' => 'A tarefa #%d foi aberta.',
    'The task #%d has been closed.' => 'A tarefa #%d foi finalizada.',
    'Sub-task updated' => 'Subtarefa atualizada',
    'Title:' => 'Título:',
    'Status:' => 'Estado:',
    'Assignee:' => 'Assignado:',
    'Time tracking:' => 'Controle de tempo:',
    'New sub-task' => 'Nova subtarefa',
    'New attachment added "%s"' => 'Novo anexo adicionado "%s"',
    'New comment posted by %s' => 'Novo comentário por %s',
    'New comment' => 'Novo comentário',
    'Comment updated' => 'Comentário actualizado',
    'New subtask' => 'Nova subtarefa',
    'I only want to receive notifications for these projects:' => 'Quero receber notificações apenas destes projetos:',
    'view the task on Kanboard' => 'ver a tarefa no Kanboard',
    'Public access' => 'Acesso público',
    'Disable public access' => 'Desactivar o acesso público',
    'Enable public access' => 'Activar o acesso público',
    'Public access disabled' => 'Acesso público desactivado',
    'Move the task to another project' => 'Mover a tarefa para outro projeto',
    'Move to project' => 'Mover para outro projeto',
    'Do you really want to duplicate this task?' => 'Tem a certeza que quer duplicar esta tarefa?',
    'Duplicate a task' => 'Duplicar uma tarefa',
    'External accounts' => 'Contas externas',
    'Account type' => 'Tipo de conta',
    'Local' => 'Local',
    'Remote' => 'Remoto',
    'Enabled' => 'Activado',
    'Disabled' => 'Desactivado',
    'Login:' => 'Utilizador:',
    'Full Name:' => 'Nome:',
    'Email:' => 'E-mail:',
    'Notifications:' => 'Notificações:',
    'Notifications' => 'Notificações',
    'Account type:' => 'Tipo de conta:',
    'Edit profile' => 'Editar perfil',
    'Change password' => 'Alterar senha',
    'Password modification' => 'Alteração de senha',
    'External authentications' => 'Autenticação externa',
    'Never connected.' => 'Nunca conectado.',
    'No external authentication enabled.' => 'Nenhuma autenticação externa activa.',
    'Password modified successfully.' => 'Senha alterada com sucesso.',
    'Unable to change the password.' => 'Não foi possível alterar a senha.',
    'Change category' => 'Mudar categoria',
    '%s updated the task %s' => '%s actualizou a tarefa %s',
    '%s opened the task %s' => '%s abriu a tarefa %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s moveu a tarefa %s para a posição #%d na coluna "%s"',
    '%s moved the task %s to the column "%s"' => '%s moveu a tarefa %s para a coluna "%s"',
    '%s created the task %s' => '%s criou a tarefa %s',
    '%s closed the task %s' => '%s finalizou a tarefa %s',
    '%s created a subtask for the task %s' => '%s criou uma subtarefa para a tarefa %s',
    '%s updated a subtask for the task %s' => '%s actualizou uma subtarefa da tarefa %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Designado para %s com tempo estimado de %s/%sh',
    'Not assigned, estimate of %sh' => 'Não assignado, estimado em %sh',
    '%s updated a comment on the task %s' => '%s actualizou o comentário na tarefa %s',
    '%s commented the task %s' => '%s comentou a tarefa %s',
    '%s\'s activity' => 'Atividades %s',
    'RSS feed' => 'Feed RSS',
    '%s updated a comment on the task #%d' => '%s actualizou um comentário sobre a tarefa #%d',
    '%s commented on the task #%d' => '%s comentou sobre a tarefa #%d',
    '%s updated a subtask for the task #%d' => '%s actualizou uma subtarefa para a tarefa #%d',
    '%s created a subtask for the task #%d' => '%s criou uma subtarefa para a tarefa #%d',
    '%s updated the task #%d' => '%s actualizou a tarefa #%d',
    '%s created the task #%d' => '%s criou a tarefa #%d',
    '%s closed the task #%d' => '%s finalizou a tarefa #%d',
    '%s opened the task #%d' => '%s abriu a tarefa #%d',
    'Activity' => 'Actividade',
    'Default values are "%s"' => 'Os valores padrão são "%s"',
    'Default columns for new projects (Comma-separated)' => 'Colunas padrão para novos projetos (Separado por vírgula)',
    'Task assignee change' => 'Mudar assignação da tarefa',
    '%s changed the assignee of the task #%d to %s' => '%s mudou a assignação da tarefa #%d para %s',
    '%s changed the assignee of the task %s to %s' => '%s mudou a assignação da tarefa %s para %s',
    'New password for the user "%s"' => 'Nova senha para o utilizador "%s"',
    'Choose an event' => 'Escolher um evento',
    'Create a task from an external provider' => 'Criar uma tarefa por meio de um serviço externo',
    'Change the assignee based on an external username' => 'Alterar assignação com base num utilizador externo',
    'Change the category based on an external label' => 'Alterar categoria com base num rótulo externo',
    'Reference' => 'Referência',
    'Label' => 'Rótulo',
    'Database' => 'Base de dados',
    'About' => 'Sobre',
    'Database driver:' => 'Driver da base de dados:',
    'Board settings' => 'Configurações do Quadro',
    'Webhook settings' => 'Configurações do Webhook',
    'Reset token' => 'Redefinir token',
    'API endpoint:' => 'API endpoint:',
    'Refresh interval for personal board' => 'Intervalo de actualização para um quadro privado',
    'Refresh interval for public board' => 'Intervalo de actualização para um quadro público',
    'Task highlight period' => 'Período de Tarefa em destaque',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Período (em segundos) para considerar que uma tarefa foi modificada recentemente (0 para desactivar, 2 dias por defeito)',
    'Frequency in second (60 seconds by default)' => 'Frequência em segundos (60 segundos por defeito)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frequência em segundos (0 para desactivar este recurso, 10 segundos por defeito)',
    'Application URL' => 'URL da Aplicação',
    'Token regenerated.' => 'Token ',
    'Date format' => 'Formato da data',
    'ISO format is always accepted, example: "%s" and "%s"' => 'O formato ISO é sempre aceite, exemplo: "%s" e "%s"',
    'New personal project' => 'Novo projeto pessoal',
    'This project is personal' => 'Este projeto é pessoal',
    'Add' => 'Adicionar',
    'Start date' => 'Data de início',
    'Time estimated' => 'Tempo estimado',
    'There is nothing assigned to you.' => 'Não há nada assignado a si.',
    'My tasks' => 'As minhas tarefas',
    'Activity stream' => 'Atividades Recentes',
    'Dashboard' => 'Painel de Controlo',
    'Confirmation' => 'Confirmação',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Criar um comentário por meio de um serviço externo',
    'Project management' => 'Gestão de projetos',
    'Columns' => 'Colunas',
    'Task' => 'Tarefas',
    'Percentage' => 'Percentagem',
    'Number of tasks' => 'Número de tarefas',
    'Task distribution' => 'Distribuição de tarefas',
    'Analytics' => 'Estatísticas',
    'Subtask' => 'Subtarefa',
    'User repartition' => 'Redistribuição de utilizador',
    'Clone this project' => 'Clonar este projeto',
    'Column removed successfully.' => 'Coluna removida com sucesso.',
    'Not enough data to show the graph.' => 'Não há dados suficientes para mostrar o gráfico.',
    'Previous' => 'Anterior',
    'The id must be an integer' => 'O ID deve ser um número inteiro',
    'The project id must be an integer' => 'O ID do projeto deve ser um inteiro',
    'The status must be an integer' => 'O estado deve ser um número inteiro',
    'The subtask id is required' => 'O ID da subtarefa é obrigatório',
    'The subtask id must be an integer' => 'O ID da subtarefa deve ser um número inteiro',
    'The task id is required' => 'O ID da tarefa é obrigatório',
    'The task id must be an integer' => 'O ID da tarefa deve ser um número inteiro',
    'The user id must be an integer' => 'O ID do utilizador deve ser um número inteiro',
    'This value is required' => 'Este valor é obrigatório',
    'This value must be numeric' => 'Este valor deve ser numérico',
    'Unable to create this task.' => 'Não foi possível criar esta tarefa.',
    'Cumulative flow diagram' => 'Fluxograma cumulativo',
    'Daily project summary' => 'Resumo diário do projeto',
    'Daily project summary export' => 'Exportação diária do resumo do projeto',
    'Exports' => 'Exportar',
    'This export contains the number of tasks per column grouped per day.' => 'Esta exportação contém o número de tarefas por coluna agrupada por dia.',
    'Active swimlanes' => 'Activar swimlanes',
    'Add a new swimlane' => 'Adicionar novo swimlane',
    'Default swimlane' => 'Swimlane padrão',
    'Do you really want to remove this swimlane: "%s"?' => 'Tem a certeza que quer remover este swimlane: "%s"?',
    'Inactive swimlanes' => 'Desactivar swimlanes',
    'Remove a swimlane' => 'Remover um swimlane',
    'Swimlane modification for the project "%s"' => 'Modificação de swimlane para o projeto "%s"',
    'Swimlane removed successfully.' => 'Swimlane removido com sucesso.',
    'Swimlanes' => 'Swimlanes',
    'Swimlane updated successfully.' => 'Swimlane atualizado com sucesso.',
    'Unable to remove this swimlane.' => 'Não foi possível remover este swimlane.',
    'Unable to update this swimlane.' => 'Não foi possível atualizar este swimlane.',
    'Your swimlane has been created successfully.' => 'Seu swimlane foi criado com sucesso.',
    'Example: "Bug, Feature Request, Improvement"' => 'Exemplo: "Bug, Feature Request, Improvement"',
    'Default categories for new projects (Comma-separated)' => 'Categorias padrão para novos projetos (Separadas por vírgula)',
    'Integrations' => 'Integrações',
    'Integration with third-party services' => 'Integração com serviços de terceiros',
    'Subtask Id' => 'ID da subtarefa',
    'Subtasks' => 'Subtarefas',
    'Subtasks Export' => 'Exportar subtarefas',
    'Task Title' => 'Título da Tarefa',
    'Untitled' => 'Sem título',
    'Application default' => 'Aplicação padrão',
    'Language:' => 'Idioma:',
    'Timezone:' => 'Fuso horário:',
    'All columns' => 'Todas as colunas',
    'Next' => 'Próximo',
    // '#%d' => '',
    'All swimlanes' => 'Todos os swimlane',
    'All colors' => 'Todas as cores',
    'Moved to column %s' => 'Mover para a coluna %s',
    'User dashboard' => 'Painel de Controlo do utilizador',
    'Allow only one subtask in progress at the same time for a user' => 'Permitir apenas uma subtarefa em andamento ao mesmo tempo para um utilizador',
    'Edit column "%s"' => 'Editar a coluna "%s"',
    'Select the new status of the subtask: "%s"' => 'Selecionar um novo estado para a subtarefa: "%s"',
    'Subtask timesheet' => 'Gestão de tempo das subtarefas',
    'There is nothing to show.' => 'Não há nada para mostrar',
    'Time Tracking' => 'Gestão de tempo',
    'You already have one subtask in progress' => 'Já tem uma subtarefa em andamento',
    'Which parts of the project do you want to duplicate?' => 'Quais as partes do projeto que deseja duplicar?',
    'Disallow login form' => 'Desactivar login',
    'Start' => 'Inicio',
    'End' => 'Fim',
    'Task age in days' => 'Idade da tarefa em dias',
    'Days in this column' => 'Dias nesta coluna',
    // '%dd' => '',
    'Add a new link' => 'Adicionar uma nova associação',
    'Do you really want to remove this link: "%s"?' => 'Tem a certeza que quer remover esta associação: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Tem a certeza que quer remover esta associação com a tarefa n°%d?',
    'Field required' => 'Campo requerido',
    'Link added successfully.' => 'Associação criada com sucesso.',
    'Link updated successfully.' => 'Associação atualizada com sucesso.',
    'Link removed successfully.' => 'Associação removida com sucesso.',
    'Link labels' => 'Etiquetas das associações',
    'Link modification' => 'Modificação de uma associação',
    'Opposite label' => 'Nome da etiqueta oposta',
    'Remove a link' => 'Remover uma associação',
    'The labels must be different' => 'As etiquetas devem ser diferentes',
    'There is no link.' => 'Não há nenhuma associação.',
    'This label must be unique' => 'Esta etiqueta deve ser unica',
    'Unable to create your link.' => 'Impossível de adicionar sua associação.',
    'Unable to update your link.' => 'Impossível de atualizar sua associação.',
    'Unable to remove this link.' => 'Impossível de remover sua associação.',
    'relates to' => 'é associada a',
    'blocks' => 'bloqueia',
    'is blocked by' => 'está bloqueada por',
    'duplicates' => 'duplica',
    'is duplicated by' => 'é duplicada por',
    'is a child of' => 'é um filha de',
    'is a parent of' => 'é um parente do',
    'targets milestone' => 'visa um objectivo',
    'is a milestone of' => 'é um objectivo de',
    'fixes' => 'corrige',
    'is fixed by' => 'foi corrigida por',
    'This task' => 'Esta tarefa',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Expandir tarefas',
    'Collapse tasks' => 'Contrair tarefas',
    'Expand/collapse tasks' => 'Expandir/Contrair tarefas',
    'Close dialog box' => 'Fechar a caixa de diálogo',
    'Submit a form' => 'Envia o formulário',
    'Board view' => 'Vista do Quadro',
    'Keyboard shortcuts' => 'Atalhos de teclado',
    'Open board switcher' => 'Abrir o comutador de painel',
    'Application' => 'Aplicação',
    'Compact view' => 'Vista reduzida',
    'Horizontal scrolling' => 'Deslocamento horizontal',
    'Compact/wide view' => 'Alternar entre a vista compacta e ampliada',
    'Currency' => 'Moeda',
    'Personal project' => 'Projeto pessoal',
    'AUD - Australian Dollar' => 'AUD - Dólar Australiano',
    'CAD - Canadian Dollar' => 'CAD - Dólar Canadense',
    'CHF - Swiss Francs' => 'CHF - Francos Suíços',
    'Custom Stylesheet' => 'Folha de estilos personalizada',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Libra Esterlina',
    'INR - Indian Rupee' => 'INR - Rúpia Indiana',
    'JPY - Japanese Yen' => 'JPY - Iene Japonês',
    'NZD - New Zealand Dollar' => 'NZD - Dólar Neozelandês',
    // 'PEN - Peruvian Sol' => '',
    'RSD - Serbian dinar' => 'RSD - Dinar Sérvio',
    'CNY - Chinese Yuan' => 'CNY - Yuan Chinês',
    'USD - US Dollar' => 'USD - Dólar Norte-americano',
    // 'VES - Venezuelan Bolívar' => '',
    'Destination column' => 'Coluna de destino',
    'Move the task to another column when assigned to a user' => 'Mover a tarefa para uma outra coluna quando esta está atribuída a um utilizador',
    'Move the task to another column when assignee is cleared' => 'Mover a tarefa para uma outra coluna quando esta não está atribuída',
    'Source column' => 'Coluna de origem',
    'Transitions' => 'Transições',
    'Executer' => 'Executor(a)',
    'Time spent in the column' => 'Tempo gasto na coluna',
    'Task transitions' => 'Transições das tarefas',
    'Task transitions export' => 'Exportação das transições das tarefas',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Este relatório contém todos os movimentos de coluna para cada tarefa com a data, o utilizador e o tempo gasto para cada transição.',
    'Currency rates' => 'Taxas de câmbio das moedas estrangeiras',
    'Rate' => 'Taxa',
    'Change reference currency' => 'Mudar a moeda de referência',
    'Reference currency' => 'Moeda de Referência',
    'The currency rate has been added successfully.' => 'A taxa de câmbio foi adicionada com sucesso.',
    'Unable to add this currency rate.' => 'Impossível adicionar essa taxa de câmbio.',
    'Webhook URL' => 'URL do webhook',
    '%s removed the assignee of the task %s' => '%s removeu a pessoa assignada à tarefa %s',
    'Information' => 'Informações',
    'Check two factor authentication code' => 'Verificação do código de autenticação com factor duplo',
    'The two factor authentication code is not valid.' => 'O código de autenticação com factor duplo não é válido',
    'The two factor authentication code is valid.' => 'O código de autenticação com factor duplo é válido',
    'Code' => 'Código',
    'Two factor authentication' => 'Autenticação com factor duplo',
    'This QR code contains the key URI: ' => 'Este Código QR contém a chave URI: ',
    'Check my code' => 'Verificar o meu código',
    'Secret key: ' => 'Chave secreta: ',
    'Test your device' => 'Teste o seu dispositivo',
    'Assign a color when the task is moved to a specific column' => 'Atribuir uma cor quando a tarefa é movida em uma coluna específica',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Gráfico de Burndown',
    'This chart show the task complexity over the time (Work Remaining).' => 'Este gráfico mostra a complexidade da tarefa ao longo do tempo (Trabalho Restante).',
    'Screenshot taken %s' => 'Screenshot tirada a %s',
    'Add a screenshot' => 'Adicionar uma Screenshot',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Tire um screenshot e pressione CTRL + V ou ⌘ + V para colar aqui.',
    'Screenshot uploaded successfully.' => 'Screenshot enviada com sucesso.',
    'SEK - Swedish Krona' => 'SEK - Coroa Sueca',
    'Identifier' => 'Identificador',
    'Disable two factor authentication' => 'Desactivar autenticação com dois factores',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Tem a certeza que quer desactivar a autenticação com dois factores para esse utilizador: "%s"?',
    'Edit link' => 'Editar um link',
    'Start to type task title...' => 'Escreva o título do trabalho...',
    'A task cannot be linked to itself' => 'Uma tarefa não pode ser ligada a si própria',
    'The exact same link already exists' => 'Um link idêntico jà existe',
    'Recurrent task is scheduled to be generated' => 'A tarefa recorrente está programada para ser criada',
    'Score' => 'Complexidade',
    'The identifier must be unique' => 'O identificador deve ser único',
    'This linked task id doesn\'t exists' => 'O identificador da tarefa associada não existe',
    'This value must be alphanumeric' => 'Este valor deve ser alfanumérico',
    'Edit recurrence' => 'Modificar a recorrência',
    'Generate recurrent task' => 'Gerar uma tarefa recorrente',
    'Trigger to generate recurrent task' => 'Activador para gerar tarefa recorrente',
    'Factor to calculate new due date' => 'Factor para o cálculo do nova data de vencimento',
    'Timeframe to calculate new due date' => 'Escala de tempo para o cálculo da nova data de vencimento',
    'Base date to calculate new due date' => 'Data a ser utilizada para calcular a nova data de vencimento',
    'Action date' => 'Data da acção',
    'Base date to calculate new due date: ' => 'Data a ser utilizada para calcular a nova data de vencimento: ',
    'This task has created this child task: ' => 'Esta tarefa criou a tarefa filha: ',
    'Day(s)' => 'Dia(s)',
    'Existing due date' => 'Data de vencimento existente',
    'Factor to calculate new due date: ' => 'Factor para calcular a nova data de vencimento: ',
    'Month(s)' => 'Mês(es)',
    'This task has been created by: ' => 'Esta tarefa foi criada por: ',
    'Recurrent task has been generated:' => 'A tarefa recorrente foi gerada:',
    'Timeframe to calculate new due date: ' => 'Escala de tempo para o cálculo da nova data de vencimento: ',
    'Trigger to generate recurrent task: ' => 'Activador para gerar tarefa recorrente: ',
    'When task is closed' => 'Quando a tarefa é fechada',
    'When task is moved from first column' => 'Quando a tarefa é movida fora da primeira coluna',
    'When task is moved to last column' => 'Quando a tarefa é movida para a última coluna',
    'Year(s)' => 'Ano(s)',
    'Project settings' => 'Configurações dos projetos',
    'Automatically update the start date' => 'Actualizar automaticamente a data de início',
    'iCal feed' => 'Subscrição iCal',
    'Preferences' => 'Preferências',
    'Security' => 'Segurança',
    'Two factor authentication disabled' => 'Autenticação com factor duplo desactivado',
    'Two factor authentication enabled' => 'Autenticação com factor duplo activado',
    'Unable to update this user.' => 'Impossível de actualizar este utilizador.',
    'There is no user management for personal projects.' => 'Não há gestão de utilizadores para projetos pessoais.',
    'User that will receive the email' => 'O utilizador que vai receber o e-mail',
    'Email subject' => 'Assunto do e-mail',
    'Date' => 'Data',
    'Add a comment log when moving the task between columns' => 'Adicionar um comentário de log quando uma tarefa é movida para uma outra coluna',
    'Move the task to another column when the category is changed' => 'Mover uma tarefa para outra coluna quando a categoria mudar',
    'Send a task by email to someone' => 'Enviar uma tarefa por e-mail a alguém',
    'Reopen a task' => 'Reabrir uma tarefa',
    'Notification' => 'Notificação',
    '%s moved the task #%d to the first swimlane' => '%s moveu a tarefa n° %d no primeiro swimlane',
    'Swimlane' => 'Swimlane',
    '%s moved the task %s to the first swimlane' => '%s moveu a tarefa %s no primeiro swimlane',
    '%s moved the task %s to the swimlane "%s"' => '%s moveu a tarefa %s no swimlane "%s"',
    'This report contains all subtasks information for the given date range.' => 'Este relatório contém informações de todas as sub-tarefas para o período selecionado.',
    'This report contains all tasks information for the given date range.' => 'Este relatório contém informações de todas as tarefas para o período selecionado.',
    'Project activities for %s' => 'Actividade do projeto "%s"',
    'view the board on Kanboard' => 'ver o painel no Kanboard',
    'The task has been moved to the first swimlane' => 'A tarefa foi movida para o primeiro Swimlane',
    'The task has been moved to another swimlane:' => 'A tarefa foi movida para outro Swimlane:',
    'New title: %s' => 'Novo título: %s',
    'The task is not assigned anymore' => 'Tarefa já não está atribuída',
    'New assignee: %s' => 'Novo assignado: %s',
    'There is no category now' => 'Já não existe categoria',
    'New category: %s' => 'Nova categoria: %s',
    'New color: %s' => 'Nova cor: %s',
    'New complexity: %d' => 'Nova complexidade: %d',
    'The due date has been removed' => 'A data de vencimento foi retirada',
    'There is no description anymore' => 'Já não há descrição',
    'Recurrence settings has been modified' => 'As configurações da recorrência foram modificadas',
    'Time spent changed: %sh' => 'O tempo despendido foi mudado: %sh',
    'Time estimated changed: %sh' => 'O tempo estimado foi mudado/ %sh',
    'The field "%s" has been updated' => 'O campo "%s" foi actualizada',
    'The description has been modified:' => 'A descrição foi modificada',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Tem a certeza que quer fechar a tarefa "%s" e todas as suas sub-tarefas?',
    'I want to receive notifications for:' => 'Eu quero receber as notificações para:',
    'All tasks' => 'Todas as tarefas',
    'Only for tasks assigned to me' => 'Somente as tarefas atribuídas a mim',
    'Only for tasks created by me' => 'Apenas as tarefas que eu criei',
    'Only for tasks created by me and tasks assigned to me' => 'Apenas as tarefas que eu criei e aquelas atribuídas a mim',
    '%%Y-%%m-%%d' => '%%d/%%m/%%Y',
    'Total for all columns' => 'Total para todas as colunas',
    'You need at least 2 days of data to show the chart.' => 'Precisa de pelo menos 2 dias de dados para visualizar o gráfico.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Parar temporizador',
    'Start timer' => 'Iniciar temporizador',
    'My activity stream' => 'O meu feed de actividade',
    'Search tasks' => 'Pesquisar tarefas',
    'Reset filters' => 'Redefinir os filtros',
    'My tasks due tomorrow' => 'A minhas tarefas que expiram amanhã',
    'Tasks due today' => 'Tarefas que expiram hoje',
    'Tasks due tomorrow' => 'Tarefas que expiram amanhã',
    'Tasks due yesterday' => 'Tarefas que expiraram ontem',
    'Closed tasks' => 'Tarefas fechadas',
    'Open tasks' => 'Tarefas abertas',
    'Not assigned' => 'Não assignada',
    'View advanced search syntax' => 'Ver sintaxe avançada de pesquisa',
    'Overview' => 'Visão global',
    'Board/Calendar/List view' => 'Vista Painel/Calendário/Lista',
    'Switch to the board view' => 'Mudar para o modo Painel',
    'Switch to the list view' => 'Mudar para o modo Lista',
    'Go to the search/filter box' => 'Ir para o campo de pesquisa',
    'There is no activity yet.' => 'Ainda não há nenhuma actividade.',
    'No tasks found.' => 'Nenhuma tarefa encontrada',
    'Keyboard shortcut: "%s"' => 'Tecla de atalho: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filtro',
    'Advanced search' => 'Pesquisa avançada',
    'Example of query: ' => 'Exemplo de consulta: ',
    'Search by project: ' => 'Pesquisar por projeto: ',
    'Search by column: ' => 'Pesquisar por coluna: ',
    'Search by assignee: ' => 'Pesquisar por assignado: ',
    'Search by color: ' => 'Pesquisar por cor: ',
    'Search by category: ' => 'Pesquisar por categoria: ',
    'Search by description: ' => 'Pesquisar por descrição: ',
    'Search by due date: ' => 'Pesquisar por data de vencimento: ',
    'Average time spent in each column' => 'Tempo médio gasto por coluna',
    'Average time spent' => 'Tempo médio gasto',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Este gráfico mostra o tempo médio gasto em cada coluna nas últimas %d tarefas.',
    'Average Lead and Cycle time' => 'Tempo de Espera e Ciclo médio',
    'Average lead time: ' => 'Tempo médio de Espera: ',
    'Average cycle time: ' => 'Tempo médio de Ciclo: ',
    'Cycle Time' => 'Tempo de Ciclo',
    'Lead Time' => 'Tempo de Espera',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Este gráfico mostra o tempo médio de espera e ciclo para as últimas %d tarefas realizadas.',
    'Average time into each column' => 'Tempo médio em cada coluna',
    'Lead and cycle time' => 'Tempo de Espera e Ciclo',
    'Lead time: ' => 'Tempo de Espera: ',
    'Cycle time: ' => 'Tempo de Ciclo: ',
    'Time spent in each column' => 'Tempo gasto em cada coluna',
    'The lead time is the duration between the task creation and the completion.' => 'O tempo de espera é a duração entre a criação e o fim da tarefa',
    'The cycle time is the duration between the start date and the completion.' => 'O tempo de ciclo é a duração entre a data de inicio e o fim da tarefa',
    'If the task is not closed the current time is used instead of the completion date.' => 'Se a tarefa não estiver fechada o hora actual será usada em vez da hora de conclusão',
    'Set the start date automatically' => 'Definir data de inicio automáticamente',
    'Edit Authentication' => 'Editar Autenticação',
    'Remote user' => 'Utilizador remoto',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Utilizadores remotos não guardam a password na base de dados do Kanboard, por exemplo: LDAP, contas do Google e Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Se activar a opção "Desactivar login", as credenciais digitadas no login serão ignoradas.',
    'Default task color' => 'Cor de tarefa por defeito',
    'This feature does not work with all browsers.' => 'Esta funcionalidade não funciona em todos os browsers',
    'There is no destination project available.' => 'Não há projeto de destino disponivel',
    'Trigger automatically subtask time tracking' => 'Activar automáticamente subtarefa de controlo de tempo',
    'Include closed tasks in the cumulative flow diagram' => 'Incluir tarefas fechadas no diagrama de fluxo acumulado',
    'Current swimlane: %s' => 'Swimlane actual: %s',
    'Current column: %s' => 'Coluna actual: %s',
    'Current category: %s' => 'Categoria actual: %s',
    'no category' => 'sem categoria',
    'Current assignee: %s' => 'Assignado a: %s',
    'not assigned' => 'não assignado',
    'Author:' => 'Autor:',
    'contributors' => 'contribuidores',
    'License:' => 'Licença:',
    'License' => 'Licença',
    'Enter the text below' => 'Escreva o texto em baixo',
    'Start date:' => 'Data de inicio:',
    'Due date:' => 'Data de vencimento:',
    'People who are project managers' => 'Pessoas que são gestores do projeto',
    'People who are project members' => 'Pessoas que são membros do projeto',
    'NOK - Norwegian Krone' => 'NOK - Coroa Norueguesa',
    'Show this column' => 'Mostrar esta coluna',
    'Hide this column' => 'Esconder esta coluna',
    'End date' => 'Data de fim',
    'Users overview' => 'Visão geral de Utilizadores',
    'Members' => 'Membros',
    'Shared project' => 'Projeto partilhado',
    'Project managers' => 'Gestores do projeto',
    'Projects list' => 'Lista de projetos',
    'End date:' => 'Data de fim:',
    'Change task color when using a specific task link' => 'Alterar cor da tarefa quando se usar um tipo especifico de ligação de tarefa',
    'Task link creation or modification' => 'Criação ou modificação de ligação de tarefa',
    'Milestone' => 'Objectivo',
    'Reset the search/filter box' => 'Repor caixa de procura/filtro',
    'Documentation' => 'Documentação',
    'Author' => 'Autor',
    'Version' => 'Versão',
    'Plugins' => 'Plugins',
    'There is no plugin loaded.' => 'Não existem extras carregados',
    'My notifications' => 'As minhas notificações',
    'Custom filters' => 'Filtros personalizados',
    'Your custom filter has been created successfully.' => 'O seu filtro personalizado foi criado com sucesso.',
    'Unable to create your custom filter.' => 'Não foi possivel criar o seu filtro personalizado.',
    'Custom filter removed successfully.' => 'Filtro personalizado removido com sucesso.',
    'Unable to remove this custom filter.' => 'Não foi possivel remover este filtro personalizado.',
    'Edit custom filter' => 'Editar filtro personalizado',
    'Your custom filter has been updated successfully.' => 'O seu filtro personalizado foi actualizado com sucesso.',
    'Unable to update custom filter.' => 'Não foi possivel actualizar o filtro personalizado.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Novo anexo na tarefa #%d: %s',
    'New comment on task #%d' => 'Novo comentário na tarefa #%d',
    'Comment updated on task #%d' => 'Comentário actualizado na tarefa #%d',
    'New subtask on task #%d' => 'Nova sub-tarefa na tarefa #%d',
    'Subtask updated on task #%d' => 'Sub-tarefa actualizada na tarefa #%d',
    'New task #%d: %s' => 'Nova tarefa #%d: %s',
    'Task updated #%d' => 'Tarefa actualizada #%d',
    'Task #%d closed' => 'Tarefa #%d fechada',
    'Task #%d opened' => 'Tarefa #%d aberta',
    'Column changed for task #%d' => 'Coluna alterada para tarefa #%d',
    'New position for task #%d' => 'Nova posição para tarefa #%d',
    'Swimlane changed for task #%d' => 'Swimlane alterado na tarefa #%d',
    'Assignee changed on task #%d' => 'Assignado alterado na tarefa #%d',
    '%d overdue tasks' => '%d tarefas em atraso',
    'Task #%d is overdue' => 'Tarefa #%d está em atraso',
    'No notification.' => 'Sem novas notificações.',
    'Mark all as read' => 'Marcar tudo como lido',
    'Mark as read' => 'Marcar como lido',
    'Total number of tasks in this column across all swimlanes' => 'Número total de tarefas nesta coluna em todas as swimlanes',
    'Collapse swimlane' => 'Colapsar swimlane',
    'Expand swimlane' => 'Expandir swimlane',
    'Add a new filter' => 'Adicionar um novo filtro',
    'Share with all project members' => 'Partilhar com todos os membros do projeto',
    'Shared' => 'Partilhado',
    'Owner' => 'Dono',
    'Unread notifications' => 'Notificações por ler',
    'Notification methods:' => 'Métodos de notificação:',
    'Unable to read your file' => 'Não foi possivel ler o ficheiro',
    '%d task(s) have been imported successfully.' => '%d tarefa(s) importada(s) com successo.',
    'Nothing has been imported!' => 'Nada foi importado',
    'Import users from CSV file' => 'Importar utilizadores de um ficheiro CSV',
    '%d user(s) have been imported successfully.' => '%d utilizadore(s) importados com successo.',
    'Comma' => 'Vírgula',
    'Semi-colon' => 'Ponto e Vírgula',
    'Tab' => 'Tabulação',
    'Vertical bar' => 'Barra vertical',
    'Double Quote' => 'Aspas',
    'Single Quote' => 'Plica',
    '%s attached a file to the task #%d' => '%s anexou um ficheiro à tarefa #%d',
    'There is no column or swimlane activated in your project!' => 'Não existe nenhuma coluna ou swimlane activado no seu projeto!',
    'Append filter (instead of replacement)' => 'Acrescentar filtro (em vez de substituir)',
    'Append/Replace' => 'Acrescentar/Substituir',
    'Append' => 'Acrescentar',
    'Replace' => 'Substituir',
    'Import' => 'Importar',
    'Change sorting' => 'alterar ordernação',
    'Tasks Importation' => 'Importação de Tarefas',
    'Delimiter' => 'Delimitador',
    'Enclosure' => 'Clausura',
    'CSV File' => 'Ficheiro CSV',
    'Instructions' => 'Instruções',
    'Your file must use the predefined CSV format' => 'O seu ficheiro tem de usar um formato CSV pre-definido',
    'Your file must be encoded in UTF-8' => 'O seu ficheiro tem de estar codificado como UTF-8',
    'The first row must be the header' => 'A primeira linha tem de ser o cabeçalho',
    'Duplicates are not verified for you' => 'Duplicados não são verificados por si',
    'The due date must use the ISO format: YYYY-MM-DD' => 'A data de expiração tem de estar no formato ISO: AAAA-MM-DD',
    'Download CSV template' => 'Descarregar template CSV',
    'No external integration registered.' => 'Nenhuma integração externa registrada.',
    'Duplicates are not imported' => 'Duplicados não são importados',
    'Usernames must be lowercase and unique' => 'Utilizadores tem de estar em letra pequena e ser unicos',
    'Passwords will be encrypted if present' => 'Senhas serão encriptadas se presentes',
    '%s attached a new file to the task %s' => '%s anexou um novo ficheiro à tarefa %s',
    'Link type' => 'Tipo de ligação',
    'Assign automatically a category based on a link' => 'Atribuir automáticamente a categoria baseada num link',
    'BAM - Konvertible Mark' => 'BAM - Marca Conversível',
    'Assignee Username' => 'Utilizador do Assignado',
    'Assignee Name' => 'Nome do Assignado',
    'Groups' => 'Grupos',
    'Members of %s' => 'Membros de %s',
    'New group' => 'Novo grupo',
    'Group created successfully.' => 'Grupo criado com sucesso.',
    'Unable to create your group.' => 'Não foi possivel criar o seu grupo.',
    'Edit group' => 'Editar grupo',
    'Group updated successfully.' => 'Grupo actualizado com sucesso.',
    'Unable to update your group.' => 'Não foi possivel actualizar o seu grupo.',
    'Add group member to "%s"' => 'Adicionar membro do grupo a "%s"',
    'Group member added successfully.' => 'Membro de grupo adicionado com sucesso.',
    'Unable to add group member.' => 'Não foi possivel adicionar membro de grupo.',
    'Remove user from group "%s"' => 'Remover utilizador do grupo "%s"',
    'User removed successfully from this group.' => 'Utilizador removido com sucesso deste grupo.',
    'Unable to remove this user from the group.' => 'Não foi possivel remover este utilizador do grupo.',
    'Remove group' => 'Remover grupo.',
    'Group removed successfully.' => 'Grupo removido com sucesso.',
    'Unable to remove this group.' => 'Não foi possivel remover este grupo.',
    'Project Permissions' => 'Permissões de Projeto',
    'Manager' => 'Gestor',
    'Project Manager' => 'Gestor de Projeto',
    'Project Member' => 'Membro de Projeto',
    'Project Viewer' => 'Visualizador de Projeto',
    'Your account is locked for %d minutes' => 'A sua conta está bloqueada por %d minutos',
    'Invalid captcha' => 'Captcha inválido',
    'The name must be unique' => 'O nome deve ser único',
    'View all groups' => 'Ver todos os grupos',
    'There is no user available.' => 'Não existe utilizador disponivel.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Tem a certeza que quer remover o utilizador "%s" do grupo "%s"?',
    'There is no group.' => 'Não existe grupo.',
    'Add group member' => 'Adicionar membro de grupo',
    'Do you really want to remove this group: "%s"?' => 'Tem a certeza que quer remover este grupo: "%s"?',
    'There is no user in this group.' => 'Não existe utilizadores neste grupo.',
    'Permissions' => 'Permissões',
    'Allowed Users' => 'Utilizadores Permitidos',
    'No specific user has been allowed.' => 'Nenhum utilizador foi especificamente permitido.',
    'Role' => 'Função',
    'Enter user name...' => 'Escreva o nome do utilizador...',
    'Allowed Groups' => 'Grupos Permitidos',
    'No group has been allowed.' => 'Nenhum grupo foi especificamente permitido.',
    'Group' => 'Grupo',
    'Group Name' => 'Nome do Grupo',
    'Enter group name...' => 'Escreva o nome do Grupo',
    'Role:' => 'Função:',
    'Project members' => 'Membros do projeto',
    '%s mentioned you in the task #%d' => '%s mencionou-te na tarefa #%d',
    '%s mentioned you in a comment on the task #%d' => '%s mencionou-te num comentário na tarefa #%d',
    'You were mentioned in the task #%d' => 'Foi mencionado na tarefa #%d',
    'You were mentioned in a comment on the task #%d' => 'Foi mencionado num comentário na tarefa #%d',
    'Estimated hours: ' => 'Horas estimadas: ',
    'Actual hours: ' => 'Horas reais: ',
    'Hours Spent' => 'Horas Gastas',
    'Hours Estimated' => 'Horas Estimadas',
    'Estimated Time' => 'Tempo Estimado',
    'Actual Time' => 'Tempo Real',
    'Estimated vs actual time' => 'Tempo estimado vs real',
    'RUB - Russian Ruble' => 'RUB - Rublo Russo',
    'Assign the task to the person who does the action when the column is changed' => 'Atribuir a tarefa à pessoa que realiza a acção quando a coluna é alterada',
    'Close a task in a specific column' => 'Fechar tarefa numa coluna especifica',
    'Time-based One-time Password Algorithm' => 'Algoritmo de password para uso único baseado em tempo',
    'Two-Factor Provider: ' => 'Provedor de Dois Passos: ',
    'Disable two-factor authentication' => 'Desactivar autenticação de dois passos',
    'Enable two-factor authentication' => 'Activar autenticação de dois passos',
    'There is no integration registered at the moment.' => 'Não existe nenhuma integração registrada até ao momento.',
    'Password Reset for Kanboard' => 'Redefinir Password para Kanboard',
    'Forgot password?' => 'Esqueceu a password?',
    'Enable "Forget Password"' => 'Activar "Esqueceu a password"',
    'Password Reset' => 'Redefinir a Password',
    'New password' => 'Nova Password',
    'Change Password' => 'Alterar Password',
    'To reset your password click on this link:' => 'Para redefinir a sua password click nesta ligação:',
    'Last Password Reset' => 'Última Redefinição da Password',
    'The password has never been reinitialized.' => 'A password nunca foi redefinida.',
    'Creation' => 'Criação',
    'Expiration' => 'Expiração',
    'Password reset history' => 'Histórico da redefinição da password',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Todas as tarefas na coluna "%s" e na swimlane "%s" foram fechadas com successo.',
    'Do you really want to close all tasks of this column?' => 'Tem a certeza que quer fechar todas as tarefas nesta coluna?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tarefa(s) na coluna "%s" e na swimlane "%s" serão fechadas.',
    'Close all tasks in this column and this swimlane' => 'Fechar todas as tarefas nesta coluna',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nenhum plugin tem registado um método de notificação do projeto. Pode continuar a configurar notificações individuais no seu perfil de utilizador.',
    'My dashboard' => 'Meu painel',
    'My profile' => 'Meu perfil',
    'Project owner: ' => 'Dono do projeto: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'O identificador do projeto é opcional e tem de ser alfa-numerico, exemplo: MEUPROJETO.',
    'Project owner' => 'Dono do projeto',
    'Personal projects do not have users and groups management.' => 'Projetos pessoais não têm gestão de utilizadores nem de grupos.',
    'There is no project member.' => 'Não existe membro do projeto.',
    'Priority' => 'Prioridade',
    'Task priority' => 'Prioridade da Tarefa',
    'General' => 'Geral',
    'Dates' => 'Datas',
    'Default priority' => 'Prioridade por defeito',
    'Lowest priority' => 'Prioridade mais baixa',
    'Highest priority' => 'Prioridade mais alta',
    'Close a task when there is no activity' => 'Fechar tarefa quando não há actividade',
    'Duration in days' => 'Duração em dias',
    'Send email when there is no activity on a task' => 'Enviar e-mail quando não há actividade numa tarefa',
    'Unable to fetch link information.' => 'Impossivel obter informação da ligação.',
    'Daily background job for tasks' => 'Trabalho diário em segundo plano para tarefas',
    'Auto' => 'Auto',
    'Related' => 'Relacionado',
    'Attachment' => 'Anexo',
    'Title not found' => 'Titulo não encontrado',
    'Web Link' => 'Ligação Web',
    'External links' => 'Ligações externas',
    'Add external link' => 'Adicionar ligação externa',
    'Type' => 'Tipo',
    'Dependency' => 'Dependencia',
    'Add internal link' => 'Adicionar ligação interna',
    'Add a new external link' => 'Adicionar nova ligação externa',
    'Edit external link' => 'Editar ligação externa',
    'External link' => 'Ligação externa',
    'Copy and paste your link here...' => 'Copie e cole a sua ligação aqui...',
    'URL' => 'URL',
    'Internal links' => 'Ligações internas',
    'Assign to me' => 'Atribuir a mim',
    'Me' => 'Eu',
    'Do not duplicate anything' => 'Não duplicar nada',
    'Projects management' => 'Gestão de projetos',
    'Users management' => 'Gestão de utilizadores',
    'Groups management' => 'Gestão de grupos',
    'Create from another project' => 'Criar apartir de outro projeto',
    'open' => 'aberto',
    'closed' => 'fechado',
    'Priority:' => 'Prioridade:',
    'Reference:' => 'Referência:',
    'Complexity:' => 'Complexidade:',
    'Swimlane:' => 'Swimlane:',
    'Column:' => 'Coluna:',
    'Position:' => 'Posição:',
    'Creator:' => 'Criador:',
    'Time estimated:' => 'Tempo estimado:',
    '%s hours' => '%s horas',
    'Time spent:' => 'Tempo gasto:',
    'Created:' => 'Criado:',
    'Modified:' => 'Modificado:',
    'Completed:' => 'Completado:',
    'Started:' => 'Iniciado:',
    'Moved:' => 'Movido:',
    'Task #%d' => 'Tarefa #%d',
    'Time format' => 'Formato tempo',
    'Start date: ' => 'Data inicio: ',
    'End date: ' => 'Data final: ',
    'New due date: ' => 'Nova data estimada: ',
    'Start date changed: ' => 'Data inicio alterada: ',
    'Disable personal projects' => 'Desactivar projetos pessoais',
    'Do you really want to remove this custom filter: "%s"?' => 'Tem a certeza que quer remover este filtro personalizado: "%s"?',
    'Remove a custom filter' => 'Remover o filtro personalizado',
    'User activated successfully.' => 'Utilizador activado com sucesso.',
    'Unable to enable this user.' => 'Não foi possivel activar este utilizador.',
    'User disabled successfully.' => 'Utilizador desactivado com sucesso.',
    'Unable to disable this user.' => 'Não foi possivel desactivar este utilizador.',
    'All files have been uploaded successfully.' => 'Todos os ficheiros foram enviados com sucesso.',
    'The maximum allowed file size is %sB.' => 'O tamanho máximo permitido é %sB.',
    'Drag and drop your files here' => 'Arraste e deixe os ficheiros para aqui',
    'choose files' => 'escolher ficheiros',
    'View profile' => 'Ver perfil',
    'Two Factor' => 'Dois Factores',
    'Disable user' => 'Desactivar utilizador',
    'Do you really want to disable this user: "%s"?' => 'Tem a certeza que quer desactivar este utilizador: "%s"?',
    'Enable user' => 'Activar utilizador',
    'Do you really want to enable this user: "%s"?' => 'Tem a certeza que quer activar este utilizador: "%s"?',
    'Download' => 'Transferir',
    'Uploaded: %s' => 'Enviado: %s',
    'Size: %s' => 'Tamanho: %s',
    'Uploaded by %s' => 'Enviado por %s',
    'Filename' => 'Nome do ficheiro',
    'Size' => 'Tamanho',
    'Column created successfully.' => 'Coluna criada com sucesso.',
    'Another column with the same name exists in the project' => 'Já existe outra coluna com o mesmo nome no projeto',
    'Default filters' => 'Filtros padrão',
    'Your board doesn\'t have any columns!' => 'O seu quadro não tem nenhuma coluna!',
    'Change column position' => 'Mudar posição da coluna',
    'Switch to the project overview' => 'Mudar para vista geral do projeto',
    'User filters' => 'Filtros de utilizador',
    'Category filters' => 'Filtros de categoria',
    'Upload a file' => 'Enviar um ficheiro',
    'View file' => 'Ver ficheiro',
    'Last activity' => 'Ultima actividade',
    'Change subtask position' => 'Mudar posição da sub-tarefa',
    'This value must be greater than %d' => 'Este valor tem de ser maior que %d',
    'Another swimlane with the same name exists in the project' => 'Já existe outra swimlane com o mesmo nome no projeto',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Exemplo: https://example.kanboard.org/ (usado para gerar URLs absolutos)',
    'Actions duplicated successfully.' => 'Acções duplicadas com sucesso.',
    'Unable to duplicate actions.' => 'Não foi possivel duplicar acções.',
    'Add a new action' => 'Adicionar nova acção',
    'Import from another project' => 'Importar de outro projeto',
    'There is no action at the moment.' => 'De momento não existe acção.',
    'Import actions from another project' => 'Importar acções de outro projeto',
    'There is no available project.' => 'Não existe projeto disponivel.',
    'Local File' => 'Ficheiro Local',
    'Configuration' => 'Configuração',
    'PHP version:' => 'Versão PHP:',
    'PHP SAPI:' => 'SAPI PHP:',
    'OS version:' => 'Versão SO:',
    'Database version:' => 'Versão base de dados:',
    'Browser:' => 'Navegador:',
    'Task view' => 'Vista de Tarefas',
    'Edit task' => 'Editar tarefa',
    'Edit description' => 'Editar descrição',
    'New internal link' => 'Nova ligação interna',
    'Display list of keyboard shortcuts' => 'Mostrar lista de atalhos do teclado',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Enviar a minha imagem de avatar',
    'Remove my image' => 'Remover a minha imagem',
    'The OAuth2 state parameter is invalid' => 'O parametro de estado do OAuth2 é inválido',
    'User not found.' => 'Utilizador não encontrado.',
    'Search in activity stream' => 'Procurar no fluxo de atividade',
    'My activities' => 'Minhas actividades',
    'Activity until yesterday' => 'Actividade até ontem',
    'Activity until today' => 'Actividade até hoje',
    'Search by creator: ' => 'Procurar por criador: ',
    'Search by creation date: ' => 'Procurar por data de criação: ',
    'Search by task status: ' => 'Procurar por estado da tarefa: ',
    'Search by task title: ' => 'Procurar por titulo da tarefa: ',
    'Activity stream search' => 'Procurar fluxo de actividade',
    'Projects where "%s" is manager' => 'Projetos onde "%s" é gestor',
    'Projects where "%s" is member' => 'Projetos onde "%s" é membro',
    'Open tasks assigned to "%s"' => 'Tarefas abertas assignadas a "%s"',
    'Closed tasks assigned to "%s"' => 'Tarefas fechadas assignadas a "%s"',
    'Assign automatically a color based on a priority' => 'Atribuir uma cor automáticamente de acordo com a prioridade',
    'Overdue tasks for the project(s) "%s"' => 'Tarefas em atraso para o(s) projeto(s) "%s"',
    'Upload files' => 'Enviar ficheiros',
    'Installed Plugins' => 'Plugins Instalados',
    'Plugin Directory' => 'Directoria de Plugins',
    'Plugin installed successfully.' => 'Plugin instalado com sucesso.',
    'Plugin updated successfully.' => 'Plugin actualizado com sucesso.',
    'Plugin removed successfully.' => 'Plugin removido com sucesso.',
    'Subtask converted to task successfully.' => 'Sub-tarefa convertida para tarefa com sucesso.',
    'Unable to convert the subtask.' => 'Não foi possivel converter a sub-tarefa.',
    'Unable to extract plugin archive.' => 'Não foi possivel extrair o arquivo do plugin.',
    'Plugin not found.' => 'Plugin não encontrado.',
    'You don\'t have the permission to remove this plugin.' => 'Não tem permissão para remover este plugin.',
    'Unable to download plugin archive.' => 'Não foi possivel transferir o arquivo do plugin.',
    'Unable to write temporary file for plugin.' => 'Não foi possivel escrever o ficheiro temporário para o plugin.',
    'Unable to open plugin archive.' => 'Não foi possivel abrir o arquivo do plugin.',
    'There is no file in the plugin archive.' => 'Ficheiro não encontrado dentro do arquivo do plugin.',
    'Create tasks in bulk' => 'Criar tarefas em massa',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Este Kanboard não está configurado para instalar plugins através do interface de utilizador.',
    'There is no plugin available.' => 'Não existe nenhum plugin instalado.',
    'Install' => 'Instalar',
    'Update' => 'Actualizar',
    'Up to date' => 'Actualizado',
    'Not available' => 'Não disponivel',
    'Remove plugin' => 'Remover plugin',
    'Do you really want to remove this plugin: "%s"?' => 'Tem a certeza que pretende remover este plugin: "%s%"?',
    'Uninstall' => 'Desinstalar',
    'Listing' => 'A Listar',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Gerir projetos',
    'Convert to task' => 'Converter para tarefa',
    'Convert sub-task to task' => 'Converter sub-tarefa para tarefa',
    'Do you really want to convert this sub-task to a task?' => 'Tem a certeza que pretende converter esta sub-tarefa para tarefa?',
    'My task title' => 'Titulo da minha tarefa',
    'Enter one task by line.' => 'Escreva uma tarefa por linha.',
    'Number of failed login:' => 'Número de logins falhados:',
    'Account locked until:' => 'Conta bloqueada até:',
    'Email settings' => 'Definições de E-mail',
    'Email sender address' => 'Endereço de envido de E-mail',
    'Email transport' => 'Transportador de E-mail',
    'Webhook token' => 'Token do Webhook',
    'Project tags management' => 'Gestão de etiquetas do Projeto',
    'Tag created successfully.' => 'Etiqueta criada com sucesso.',
    'Unable to create this tag.' => 'Não foi possivel criar esta etiqueta.',
    'Tag updated successfully.' => 'Etiqueta actualizada com sucesso.',
    'Unable to update this tag.' => 'Não foi possivel actualizar esta etiqueta.',
    'Tag removed successfully.' => 'Etiqueta removida com sucesso.',
    'Unable to remove this tag.' => 'Não foi possivel remover esta etiqueta.',
    'Global tags management' => 'Gestão de etiquetas globais',
    'Tags' => 'Etiquetas',
    'Tags management' => 'Gestão de Etiquetas',
    'Add new tag' => 'Adicionar etiqueta nova',
    'Edit a tag' => 'Editar a etiqueta',
    'Project tags' => 'Etiquetas do Projeto',
    'There is no specific tag for this project at the moment.' => 'De momento não existe nenhuma etiqueta para este projeto.',
    'Tag' => 'Etiqueta',
    'Remove a tag' => 'Remover etiqueta',
    'Do you really want to remove this tag: "%s"?' => 'Tem a certeza que pretende remover esta etiqueta: "%s"?',
    'Global tags' => 'Etiquetas globais',
    'There is no global tag at the moment.' => 'De momento não existe nenhuma etiqueta global.',
    'This field cannot be empty' => 'Este campo não pode ficar vazio',
    'Close a task when there is no activity in a specific column' => 'Fechar tarefa quando não houver actividade numa coluna especifica',
    '%s removed a subtask for the task #%d' => '%s removeu uma sub-tarefa da tarefa #%d',
    '%s removed a comment on the task #%d' => '%s removeu um comentário da tarefa #%d ',
    'Comment removed on task #%d' => 'Comentário removido da tarefa #%d',
    'Subtask removed on task #%d' => 'Sub-tarefa removida da tarefa #%d',
    'Hide tasks in this column in the dashboard' => 'Esconder do meu painel tarefas nesta coluna',
    '%s removed a comment on the task %s' => '%s removeu um comentário da tarefa %s',
    '%s removed a subtask for the task %s' => '%s removeu uma sub-tarefa da tarefa %s',
    'Comment removed' => 'Comentário removido',
    'Subtask removed' => 'Sub-tarefa removida',
    '%s set a new internal link for the task #%d' => '%s definiu uma nova ligação interna para a tarefa #%d',
    '%s removed an internal link for the task #%d' => '%s removeu uma ligação interna da tarefa #%d',
    'A new internal link for the task #%d has been defined' => 'Uma nova ligação para a tarea #%d foi definida',
    'Internal link removed for the task #%d' => 'Ligação interna removida da tarefa #%d',
    '%s set a new internal link for the task %s' => '%s definiu uma nova ligação interna para a tarefa %s',
    '%s removed an internal link for the task %s' => '%s removeu uma ligação interna da tarefa %s',
    'Automatically set the due date on task creation' => 'Definir data de vencimento automáticamente ao criar uma tarefa',
    'Move the task to another column when closed' => 'Mover a tarefa para outra coluna quando fechada',
    'Move the task to another column when not moved during a given period' => 'Mover a tarefa para outra coluna quando não movida dentro de determinado periodo',
    'Dashboard for %s' => 'Painel de %s',
    'Tasks overview for %s' => 'Vista geral das tarefas de %s',
    'Subtasks overview for %s' => 'Vista geral das sub-tarefas de %s',
    'Projects overview for %s' => 'Vista geral dos projetos de %s',
    'Activity stream for %s' => 'Fluxo de actividade de %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Atribuir uma cor quando a tarefa é movida para uma swimlane especifica',
    'Assign a priority when the task is moved to a specific swimlane' => 'Atribuir uma prioridade quando a tarefa é movida para uma swimlane especifica',
    'User unlocked successfully.' => 'Utilizador desbloqueado com sucesso.',
    'Unable to unlock the user.' => 'Não foi possivel desbloquear o utilizador.',
    'Move a task to another swimlane' => 'Mover a tarefa para outra swimlane',
    'Creator Name' => 'Nome do Criador',
    'Time spent and estimated' => 'Tempo gasto e estimado',
    'Move position' => 'Mover posição',
    'Move task to another position on the board' => 'Mover tarefa para outra posição no quadro',
    'Insert before this task' => 'Inserir antes desta tarefa',
    'Insert after this task' => 'Inserir depois desta tarefa',
    'Unlock this user' => 'Desbloquear este utilizador',
    'Custom Project Roles' => 'Funções Personalizadas do Projeto',
    'Add a new custom role' => 'Adicionar uma nova função personalizada',
    'Restrictions for the role "%s"' => 'Restrições para a função: "%s"',
    'Add a new project restriction' => 'Adicionar uma nova restrição de Projeto',
    'Add a new drag and drop restriction' => 'Adicionar uma nova restrição de arrastar e largar',
    'Add a new column restriction' => 'Adicionar uma nova restrição de colunas',
    'Edit this role' => 'Editar esta função',
    'Remove this role' => 'Remover esta função',
    'There is no restriction for this role.' => 'Não existem restrições para esta função.',
    'Only moving task between those columns is permitted' => 'Só é permitido mover a tarefa entre as seguintes colunas',
    'Close a task in a specific column when not moved during a given period' => 'Fecha a tarefa numa coluna especifica quando não é movimentada durante um dado periodo',
    'Edit columns' => 'Editar colunas',
    'The column restriction has been created successfully.' => 'A restrição de coluna foi criada com sucesso.',
    'Unable to create this column restriction.' => 'Não foi possivel criar esta restrição de coluna.',
    'Column restriction removed successfully.' => 'Restrição de coluna removida com sucesso.',
    'Unable to remove this restriction.' => 'Não foi possivel remover esta restrição.',
    'Your custom project role has been created successfully.' => 'O sua função de projeto personalizada foi criada com sucesso.',
    'Unable to create custom project role.' => 'Não foi possivel criar a função de projeto personalizada.',
    'Your custom project role has been updated successfully.' => 'A sua função de projeto personalizada foi atualizada com sucesso.',
    'Unable to update custom project role.' => 'Não foi possivel atualizar a função de projeto personalizada.',
    'Custom project role removed successfully.' => 'Função de projeto removida com sucesso.',
    'Unable to remove this project role.' => 'Não foi possivel remover esta função de projeto.',
    'The project restriction has been created successfully.' => 'A restrição de projeto foi criada com sucesso.',
    'Unable to create this project restriction.' => 'Não foi possivel remover esta restrição de projeto.',
    'Project restriction removed successfully.' => 'Restrição de projeto removida com sucesso.',
    'You cannot create tasks in this column.' => 'Não pode criar tarefas nesta coluna.',
    'Task creation is permitted for this column' => 'A criação de tarefas é permitida nesta coluna',
    'Closing or opening a task is permitted for this column' => 'Fechar ou abrir tarefas é permitido nesta coluna',
    'Task creation is blocked for this column' => 'A criação de tarefas está bloqueada nesta coluna',
    'Closing or opening a task is blocked for this column' => 'Fechar ou abrir tarefas está bloqueado nesta coluna',
    'Task creation is not permitted' => 'A criação de tarefas não é permitida',
    'Closing or opening a task is not permitted' => 'Fechar ou abrir tarefas não é permitido',
    'New drag and drop restriction for the role "%s"' => 'Nova restrição de arrastar e largar para a função: "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Pessoas pertecentes a esta função poderam mover terefas só entre as colunas de origem e de destino.',
    'Remove a column restriction' => 'Remover a restrição de coluna',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Tem a certeza que quer remover a restrição de coluna: "%s" para "%s"?',
    'New column restriction for the role "%s"' => 'Nova restrição de coluna para a função: "%s"',
    'Rule' => 'Regra',
    'Do you really want to remove this column restriction?' => 'Tem a certeza que quer remover esta restrição de coluna?',
    'Custom roles' => 'Funções personalizadas',
    'New custom project role' => 'Nova função de projeto personalizada',
    'Edit custom project role' => 'Editar função de projeto personalizada',
    'Remove a custom role' => 'Remover função de projeto personalizada',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Tem a certeza que quer remover esta função personalizada: "%s"? Todas as pessoas atribuídas a esta função ficarão membros do projecto.',
    'There is no custom role for this project.' => 'Não existem funções personalizadas para este projeto',
    'New project restriction for the role "%s"' => 'Nova restrição de projeto para a função: "%s"',
    'Restriction' => 'Restrição',
    'Remove a project restriction' => 'Remover uma restrição de projeto',
    'Do you really want to remove this project restriction: "%s"?' => 'Tem a certeza que quer remover a restrição de projeto: "%s"?',
    'Duplicate to multiple projects' => 'Duplicar para vários projetos',
    'This field is required' => 'Este campo é obrigatório',
    'Moving a task is not permitted' => 'Não é permitido mover uma tarefa',
    'This value must be in the range %d to %d' => 'Este valor deve estar entre %d e %d',
    'You are not allowed to move this task.' => 'Não lhe é permitido mover esta tarefa.',
    'API User Access' => 'Acesso de Utilizador ao API',
    'Preview' => 'Pré-Visualizar',
    'Write' => 'Escrever',
    'Write your text in Markdown' => 'Escreva o seu texto em Markdown',
    'No personal API access token registered.' => 'Nenhum token pessoal de acesso ao API ',
    'Your personal API access token is "%s"' => 'O seu token de acesso pessoal ao API é "%s"',
    'Remove your token' => 'Remover o seu token',
    'Generate a new token' => 'Gerar um novo token',
    'Showing %d-%d of %d' => 'A mostrar %d-%d de %d',
    'Outgoing Emails' => 'E-mails de saída',
    'Add or change currency rate' => 'Adicionar ou alterar taxa da moeda',
    'Reference currency: %s' => 'Moeda de referência: %s',
    'Add custom filters' => 'Adicionar filtros personalizados',
    'Export' => 'Exportar',
    'Add link label' => 'Adicionar etiqueta de associação',
    'Incompatible Plugins' => 'Plugins incompatíveis',
    'Compatibility' => 'Compatibilidade',
    'Permissions and ownership' => 'Permissões e propriedade',
    'Priorities' => 'Prioridades',
    'Close this window' => 'Feche esta janela',
    'Unable to upload this file.' => 'Não foi possível enviar este ficheiro.',
    'Import tasks' => 'Importar tarefas',
    'Choose a project' => 'Escolha um projeto',
    'Profile' => 'Perfil',
    'Application role' => 'Função na Aplicação',
    '%d invitations were sent.' => '%d convites foram enviados.',
    '%d invitation was sent.' => '%d convite foi enviado.',
    'Unable to create this user.' => 'Não foi possível criar este utilizador.',
    'Kanboard Invitation' => 'Convite de Kanboard',
    'Visible on dashboard' => 'Visível no painel',
    'Created at:' => 'Criado a:',
    'Updated at:' => 'Atualizado a:',
    'There is no custom filter.' => 'Não existe nenhum filtro personalizado.',
    'New User' => 'Novo Utilizador',
    'Authentication' => 'Autenticação',
    'If checked, this user will use a third-party system for authentication.' => 'Se selecionado, este utilizador irá utilizar um serviços de terceiros para autenticação.',
    'The password is necessary only for local users.' => 'A password só é necessária para utilizadores locais.',
    'You have been invited to register on Kanboard.' => 'Foi convidado para se registrar no Kanboard.',
    'Click here to join your team' => 'Clique aqui para se juntar à sua equipa',
    'Invite people' => 'Convidar pessoas',
    'Emails' => 'E-mails',
    'Enter one email address by line.' => 'Insira um endereço de e-mail por linha.',
    'Add these people to this project' => 'Adicione estas pessoas a este projeto',
    'Add this person to this project' => 'Adicione esta pessoa a este projeto',
    'Sign-up' => 'Registe-se',
    'Credentials' => 'Credenciais',
    'New user' => 'Novo utilizador',
    'This username is already taken' => 'Este nome de utilizador já está a ser utilizado',
    'Your profile must have a valid email address.' => 'O seu perfil deve ter um endereço de email válido.',
    'TRL - Turkish Lira' => 'TRL - Lira Turca',
    'The project email is optional and could be used by several plugins.' => 'O e-mail do projeto é opcional e pode ser usado por vários plugins.',
    'The project email must be unique across all projects' => 'O e-mail do projeto tem de ser único em todos os projetos',
    'The email configuration has been disabled by the administrator.' => 'A configuração de e-mail foi desativada pelo administrador.',
    'Close this project' => 'Fechar este projeto',
    'Open this project' => 'Abrir este projeto',
    'Close a project' => 'Fechar um projeto',
    'Do you really want to close this project: "%s"?' => 'Deseja realmente fechar este projeto: "%s"?',
    'Reopen a project' => 'Reabrir um projeto',
    'Do you really want to reopen this project: "%s"?' => 'Deseja mesmo reabrir este projecto?: "%s"?',
    'This project is open' => 'Este projeto está aberto',
    'This project is closed' => 'Este projecto está fechado',
    'Unable to upload files, check the permissions of your data folder.' => 'Impossivel enviar ficheiros, verifique as permissões da pasta data',
    'Another category with the same name exists in this project' => 'Outra categoria com o mesmo nome já existe neste projecto',
    'Comment sent by email successfully.' => 'Comentário enviado por email com sucesso.',
    'Sent by email to "%s" (%s)' => 'Enviado por email para "%s" (%s)',
    'Unable to read uploaded file.' => 'Não foi possivel ler ficheiro enviado.',
    'Database uploaded successfully.' => 'Base de dados enviada com sucesso.',
    'Task sent by email successfully.' => 'Tarefa enviada por email com sucesso.',
    'There is no category in this project.' => 'Não existe categorias neste projecto.',
    'Send by email' => 'Enviar por email',
    'Create and send a comment by email' => 'Criar e enviar um comentário por email',
    'Subject' => 'Assunto',
    'Upload the database' => 'Enviar a base de dados',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Poderia enviar a base de dados Sqlite transferida anteriormente (formato Gzip).',
    'Database file' => 'Ficheiro base de dados',
    'Upload' => 'Enviar',
    'Your project must have at least one active swimlane.' => 'O seu projecto deve ter pelo menos uma swimlane activa.',
    'Project: %s' => 'Projecto: %s',
    'Automatic action not found: "%s"' => 'Acção automática não encontrada: "%s"',
    '%d projects' => '%d projetos',
    '%d project' => '%d projecto',
    'There is no project.' => 'Não existe projecto.',
    'Sort' => 'Ordenar',
    'Project ID' => 'ID do Projecto',
    'Project name' => 'Nome do Projecto',
    'Public' => 'Público',
    'Personal' => 'Privado',
    '%d tasks' => '%d tarefas',
    '%d task' => '%d tarefa',
    'Task ID' => 'ID da Tarefa',
    'Assign automatically a color when due date is expired' => 'Atribuir automaticamente uma cor quando a data de vencimento expirar',
    'Total score in this column across all swimlanes' => 'Pontuação total nesta coluna em todos os swimlanes',
    'HRK - Kuna' => 'HRK - Kuna Croata',
    'ARS - Argentine Peso' => 'ARS - Peso Argentino',
    'COP - Colombian Peso' => 'COP - Peso Colombiano',
    '%d groups' => '%d grupos',
    '%d group' => '%d grupo',
    'Group ID' => 'ID do Grupo',
    'External ID' => 'ID Externo',
    '%d users' => '%d utilizadores',
    '%d user' => '%d utilizador',
    'Hide subtasks' => 'Esconder subtarefas',
    'Show subtasks' => 'Mostrar subtarefas',
    'Authentication Parameters' => 'Parâmetros de autenticação',
    'API Access' => 'Acesso à API',
    'No users found.' => 'Não foram encontrados utilizadores.',
    'User ID' => 'ID de Utilizador',
    'Notifications are activated' => 'Notificações ativadas',
    'Notifications are disabled' => 'Notificações desativadas',
    'User disabled' => 'Utilizador desactivado',
    '%d notifications' => '%d notificações',
    '%d notification' => '%d notificação',
    'There is no external integration installed.' => 'Não há integração externa instalada.',
    'You are not allowed to update tasks assigned to someone else.' => 'Não tem permissão para atualizar tarefas atribuídas a outra pessoa.',
    'You are not allowed to change the assignee.' => 'Não tem permissão para alterar a atribuição',
    'Task suppression is not permitted' => 'A supressão de tarefas não é permitida',
    'Changing assignee is not permitted' => 'Não é permitido alterar a atribuição',
    'Update only assigned tasks is permitted' => 'Apenas é permitido atualizar as tarefas atribuídas',
    'Only for tasks assigned to the current user' => 'Apenas para tarefas atribuídas ao utilizador atual',
    'My projects' => 'Meus projetos',
    'You are not a member of any project.' => 'Não é membro de nenhum projeto.',
    'My subtasks' => 'Minhas subtarefas',
    '%d subtasks' => '%d subtarefas',
    '%d subtask' => '%d subtarefa',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Apenas é permitido mover a tarefa entre essas colunas para tarefas atribuídas ao utilizador atual',
    '[DUPLICATE]' => '[DUPLICADA]',
    'DKK - Danish Krona' => 'DKK - Coroa Dinamarquesa',
    'Remove user from group' => 'Remover utilizador do grupo',
    'Assign the task to its creator' => 'Atribuir a tarefa ao seu criador',
    'This task was sent by email to "%s" with subject "%s".' => 'Esta tarefa foi enviada por email para "%s" com o assunto "%s".',
    'Predefined Email Subjects' => 'Assuntos de email predefinidos',
    'Write one subject by line.' => 'Escreva um assunto por linha.',
    'Create another link' => 'Criar outro link',
    'BRL - Brazilian Real' => 'BRL - Real Brasileiro',
    'Add a new Kanboard task' => 'Adicionar nova tarefa Kanboard',
    'Subtask not started' => 'Sub-tarefa não iniciada',
    'Subtask currently in progress' => 'Sub-tarefa em progresso',
    'Subtask completed' => 'Sub-tarefa concluida',
    'Subtask added successfully.' => 'Sub-tarefa adicionada com sucesso.',
    '%d subtasks added successfully.' => '%d sub-tarefas adicionadas com sucesso.',
    'Enter one subtask by line.' => 'Escreva uma sub-tarefa por linha.',
    'Predefined Contents' => 'Conteudos Predefinidos',
    'Predefined contents' => 'Conteudos predefinidos',
    'Predefined Task Description' => 'Descricção de Tarefa Predefinida',
    'Do you really want to remove this template? "%s"' => 'Tem a certeza que pretende remover este template? "%s"',
    'Add predefined task description' => 'Adicionar descrição predefinida de tarefa',
    'Predefined Task Descriptions' => 'Descrições Predefinidas de Tarefa',
    'Template created successfully.' => 'Template criado com sucesso.',
    'Unable to create this template.' => 'Não foi possivel criar este template.',
    'Template updated successfully.' => 'Template actualizado com sucesso.',
    'Unable to update this template.' => 'Não foi possivel actualizar este template.',
    'Template removed successfully.' => 'Template removido com sucesso.',
    'Unable to remove this template.' => 'Não foi possivel remover este template.',
    'Template for the task description' => 'Template para descrição de tarefa',
    'The start date is greater than the end date' => 'A data de inicio é maior que a data de fim',
    'Tags must be separated by a comma' => 'Etiquetas tem de ser separadas por virgula',
    'Only the task title is required' => 'Apenas o titulo da tarefa é necessário',
    'Creator Username' => 'Utilizador do Criador',
    'Color Name' => 'Nome da Cor',
    'Column Name' => 'Noma da Coluna',
    'Swimlane Name' => 'Nome da Swimlane',
    'Time Estimated' => 'Tempo Estimado',
    'Time Spent' => 'Tempo Gasto',
    'External Link' => 'Ligação Externa',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Esta característica activa a feed do iCal, a feed do RSS e a vista publica do quadro.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Parar o temporizador de todas as sub-tarefas quando a tarefa for movida para outra coluna',
    'Subtask Title' => 'Titulo de sub-tarefa',
    'Add a subtask and activate the timer when moving a task to another column' => 'Adicionar uma sub-tarefa e activar o temporizador quando a tarefa for movida para outra coluna',
    'days' => 'dias',
    'minutes' => 'minutos',
    'seconds' => 'segundos',
    'Assign automatically a color when preset start date is reached' => 'Atribuir automaticamente uma cor quando a data de início for atingida',
    'Move the task to another column once a predefined start date is reached' => 'Mover a tarefa para outra coluna quando a data de início for atingida',
    'This task is now linked to the task %s with the relation "%s"' => 'Esta tarefa está agora ligada à tarefa %s com a relação "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'A ligação com a relação "%s" à tarefa %s foi removida',
    'Custom Filter:' => 'Filtro Personalizado:',
    'Unable to find this group.' => 'Não foi possivel encontrar este grupo.',
    '%s moved the task #%d to the column "%s"' => '%s moveu a tarefa #%d para a coluna "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s moveu a tarefa #%d para a posição %d na coluna "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s moveu a tarefa #%d para a swimlane "%s"',
    '%sh spent' => '%sh gastas',
    '%sh estimated' => '%sh estimadas',
    'Select All' => 'Selecionar Tudo',
    'Unselect All' => 'Desmarcar Tudo',
    'Apply action' => 'Aplicar ação',
    'Move selected tasks to another column or swimlane' => 'Mover tarefas selecionadas para outra coluna',
    'Edit tasks in bulk' => 'Editar tarefas em massa',
    'Choose the properties that you would like to change for the selected tasks.' => 'Escolha as propriedades que pretente modificar nas tarefas selecionadas.',
    'Configure this project' => 'Configurar este projeto',
    'Start now' => 'Começar agora',
    '%s removed a file from the task #%d' => '%s removeu um ficheiro da tarefa #%d',
    'Attachment removed from task #%d: %s' => 'Anexo removido da tarefa #%d: %s',
    'No color' => 'Sem cor',
    'Attachment removed "%s"' => 'Anexo removido "%s"',
    '%s removed a file from the task %s' => '%s removeu um ficheiro da tarefa %s',
    'Move the task to another swimlane when assigned to a user' => 'Mover a tarefa para outra swimlane quando assignada a um utilizador',
    'Destination swimlane' => 'Swimlane de destino',
    'Assign a category when the task is moved to a specific swimlane' => 'Assignar uma categoria quando a tarefa é movida para um swimlane especifica',
    'Move the task to another swimlane when the category is changed' => 'Mover a tarefa para outra swimlane quando a categoria é alterada',
    'Reorder this column by priority (ASC)' => 'Reordenar esta coluna por prioridade (ASC)',
    'Reorder this column by priority (DESC)' => 'Reordenar esta coluna por prioridade (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Reordenar esta coluna por assignado e prioridade (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Reordenar esta coluna por assignado e prioridade (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Reordenar esta coluna por assignado (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Reordenar esta coluna por assignado (Z-A)',
    'Reorder this column by due date (ASC)' => 'Reordenar esta coluna por data de vencimento (ASC)',
    'Reorder this column by due date (DESC)' => 'Reordenar esta coluna por data de vencimento (DESC)',
    // 'Reorder this column by id (ASC)' => '',
    // 'Reorder this column by id (DESC)' => '',
    '%s moved the task #%d "%s" to the project "%s"' => '%s moveu a tarefa #%d "%s" para o projeto "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Tarefa #%d "%s" foi movida para o projeto "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Mover a tarefa para outra coluna quando a data de vencimento é menos que um certo numero de dias',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automaticamente atualizar a data de inicio quando a tarefa for movida de uma certa coluna',
    'HTTP Client:' => 'Cliente HTTP:',
    'Assigned' => 'Assignado',
    'Task limits apply to each swimlane individually' => 'Limites de tarefa aplicam-se a cada swimlane individualmente',
    'Column task limits apply to each swimlane individually' => 'Limites de tarefas da coluna aplicam-se a cada swimlane individualmente',
    'Column task limits are applied to each swimlane individually' => 'Limites de tarefas da coluna são aplicadas a cada swimlane individualmente',
    'Column task limits are applied across swimlanes' => 'Limites de tarefas da coluna são aplicados a todas a swimlanes',
    'Task limit: ' => 'Limite da tarefa: ',
    'Change to global tag' => 'Alterar para etiqueta global',
    'Do you really want to make the tag "%s" global?' => 'Tem a certeza que pretende por a etiqueta "%s" como global?',
    'Enable global tags for this project' => 'Activar etiquetas globais para este projeto',
    'Group membership(s):' => 'Membro(s) do grupo:',
    '%s is a member of the following group(s): %s' => '%s é membro do(s) seguinte(s) grupo(s): %s',
    '%d/%d group(s) shown' => '%d/%d grupo(s) mostrado(s)',
    'Subtask creation or modification' => 'Alteração ou criação de sub-tarefa',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Assignar a tarefa a um utilizador especificado quando a tarefa é movida para uma swimlane especificada',
    'Comment' => 'Comentário',
    'Collapse vertically' => 'Colapsar verticalmente',
    'Expand vertically' => 'Expandir verticalmente',
    'MXN - Mexican Peso' => 'MXN - Peso Mexicano',
    'Estimated vs actual time per column' => 'Tempo estimado vs real por coluna',
    'HUF - Hungarian Forint' => 'HUF - Florim Húngaro',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Tem selecionar um ficheiro para carregar como seu avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'O ficheiro que carregou não uma imagem válida! (Apenas *.gif, *.jpg, *.jpeg e *.png são permitidas!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Definir automaticamente a data de vencimento quando a tarefa for arrastada de uma coluna específica',
    // 'No other projects found.' => '',
    // 'Please choose a project you want to copy the tasks from.' => '',
    // 'Import Tasks' => '',
    // 'Copy' => '',
    // 'Tasks copied successfully.' => '',
    // 'Unable to copy tasks.' => '',
    // 'Theme' => '',
    // 'Theme:' => '',
    // 'Light theme' => '',
    // 'Dark theme' => '',
    // 'Automatic theme - Sync with system' => '',
    // 'Application managers or more' => '',
    // 'Administrators' => '',
    // 'Visibility:' => '',
    // 'Standard users' => '',
    // 'Visibility is required' => '',
    // 'The visibility should be an app role' => '',
    // 'Reply' => '',
    // '%s wrote: ' => '',
    // 'Number of visible tasks in this column and swimlane' => '',
    // 'Number of tasks in this swimlane' => '',
    // 'Unable to find another subtask in progress, you can close this window.' => '',
    // 'This theme is invalid' => '',
    // 'This role is invalid' => '',
    // 'This timezone is invalid' => '',
    // 'This language is invalid' => '',
    // 'This URL is invalid' => '',
    // 'Date format invalid' => '',
    // 'Time format invalid' => '',
    // 'Invalid Mail transport' => '',
    // 'Color invalid' => '',
    // 'This value must be greater or equal to %d' => '',
    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
    // 'Just add these tag(s)' => '',
    // 'Remove internal link(s)' => '',
);
